==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaInformacjaDodatkowaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaInformacjaDodatkowaKey extends GenericDPSObject {
    /**
     * DIAGNOZA_INFORMACJA_DODATKOWA.DIAGNOZA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long diagnozaId;

    /**
     * DIAGNOZA_INFORMACJA_DODATKOWA.INFORMACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long informacjaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_INFORMACJA_DODATKOWA.DIAGNOZA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDiagnozaId() {
        return diagnozaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_INFORMACJA_DODATKOWA.DIAGNOZA_ID
     *
     * @param diagnozaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDiagnozaId(Long diagnozaId) {
        this.diagnozaId = diagnozaId;
    }

    /**
     * @return DIAGNOZA_INFORMACJA_DODATKOWA.INFORMACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInformacjaId() {
        return informacjaId;
    }

    /**
     * DIAGNOZA_INFORMACJA_DODATKOWA.INFORMACJA_ID
     *
     * @param informacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInformacjaId(Long informacjaId) {
        this.informacjaId = informacjaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaInformacjaDodatkowaKey other = (DiagnozaInformacjaDodatkowaKey) that;
        return (this.getDiagnozaId() == null ? other.getDiagnozaId() == null : this.getDiagnozaId().equals(other.getDiagnozaId()))
            && (this.getInformacjaId() == null ? other.getInformacjaId() == null : this.getInformacjaId().equals(other.getInformacjaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDiagnozaId() == null) ? 0 : getDiagnozaId().hashCode());
        result = prime * result + ((getInformacjaId() == null) ? 0 : getInformacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", diagnozaId=").append(diagnozaId);
        sb.append(", informacjaId=").append(informacjaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaInformacjaDodatkowaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaInformacjaDodatkowaKey extends GenericDPSObject {
    /**
     * DIAGNOZA_INFORMACJA_DODATKOWA.DIAGNOZA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long diagnozaId;

    /**
     * DIAGNOZA_INFORMACJA_DODATKOWA.INFORMACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long informacjaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_INFORMACJA_DODATKOWA.DIAGNOZA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDiagnozaId() {
        return diagnozaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_INFORMACJA_DODATKOWA.DIAGNOZA_ID
     *
     * @param diagnozaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDiagnozaId(Long diagnozaId) {
        this.diagnozaId = diagnozaId;
    }

    /**
     * @return DIAGNOZA_INFORMACJA_DODATKOWA.INFORMACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInformacjaId() {
        return informacjaId;
    }

    /**
     * DIAGNOZA_INFORMACJA_DODATKOWA.INFORMACJA_ID
     *
     * @param informacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInformacjaId(Long informacjaId) {
        this.informacjaId = informacjaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaInformacjaDodatkowaKey other = (DiagnozaInformacjaDodatkowaKey) that;
        return (this.getDiagnozaId() == null ? other.getDiagnozaId() == null : this.getDiagnozaId().equals(other.getDiagnozaId()))
            && (this.getInformacjaId() == null ? other.getInformacjaId() == null : this.getInformacjaId().equals(other.getInformacjaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDiagnozaId() == null) ? 0 : getDiagnozaId().hashCode());
        result = prime * result + ((getInformacjaId() == null) ? 0 : getInformacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", diagnozaId=").append(diagnozaId);
        sb.append(", informacjaId=").append(informacjaId);
        sb.append("]");
        return sb.toString();
    }
}
